@@ -171,6 +171,8 @@ _rsvg_node_text_type_children(RsvgNode * self, RsvgDrawingCtx *ctx,
 							  gdouble * x, gdouble * y, gboolean * lastwasspace)
 {
 	guint i;
+
+	rsvg_push_discrete_layer(ctx);
 	for (i = 0; i < self->children->len; i++)
 		{
 			RsvgNode * node = g_ptr_array_index(self->children, i);
@@ -194,6 +196,7 @@ _rsvg_node_text_type_children(RsvgNode * self, RsvgDrawingCtx *ctx,
 					_rsvg_node_text_type_tref(tref, ctx, x, y, lastwasspace);
 				}
 		}		
+	rsvg_pop_discrete_layer(ctx);
 }
 
 static int
@@ -562,7 +565,7 @@ rsvg_text_layout_get_offsets (RsvgTextLayout *layout,
 	}
 	
 	*x = MIN (ink.x, logical.x);
-	*y = MAX (ink.y, logical.y);
+	*y = MIN (ink.y, logical.y);
 }
 
 static FT_Int32
